import React from 'react';
import { 
  StyleSheet, 
  View, 
  Text, 
  Image, 
  TouchableOpacity, 
  Dimensions 
} from 'react-native';

const { width } = Dimensions.get('window');
const cardWidth = (width - 45) / 2; // 2 columns with padding

interface ContentCardProps {
  item: any;
  onPress: () => void;
}

const ContentCard = ({ item, onPress }: ContentCardProps) => {
  // Determine the right title field based on content type
  const getTitle = () => {
    if (item.title) return item.title;
    if (item.name) return item.name;
    return 'محتوى بدون عنوان';
  };

  // Get appropriate thumbnail image
  const getThumbnail = () => {
    if (item.posterUrl) return { uri: item.posterUrl };
    if (item.thumbnailUrl) return { uri: item.thumbnailUrl };
    if (item.logoUrl) return { uri: item.logoUrl };
    return require('../assets/placeholder.png'); // Make sure to add a placeholder image
  };

  // Get badge text based on content type
  const getBadge = () => {
    switch (item.type) {
      case 'movie':
        return 'فيلم';
      case 'series':
        return 'مسلسل';
      case 'channel':
        return 'قناة';
      case 'match':
        return 'مباراة';
      default:
        return '';
    }
  };

  return (
    <TouchableOpacity style={styles.container} onPress={onPress}>
      <View style={styles.card}>
        <Image
          source={getThumbnail()}
          style={styles.image}
          resizeMode="cover"
        />
        <View style={styles.badge}>
          <Text style={styles.badgeText}>{getBadge()}</Text>
        </View>
      </View>
      <Text style={styles.title} numberOfLines={1}>{getTitle()}</Text>
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  container: {
    width: cardWidth,
    marginBottom: 15,
  },
  card: {
    width: '100%',
    height: cardWidth * 1.5,
    borderRadius: 8,
    overflow: 'hidden',
    backgroundColor: '#333',
    position: 'relative',
  },
  image: {
    width: '100%',
    height: '100%',
  },
  badge: {
    position: 'absolute',
    top: 8,
    right: 8,
    backgroundColor: '#E50914',
    paddingHorizontal: 8,
    paddingVertical: 4,
    borderRadius: 4,
  },
  badgeText: {
    color: 'white',
    fontSize: 10,
    fontWeight: 'bold',
  },
  title: {
    color: 'white',
    fontSize: 14,
    marginTop: 8,
    textAlign: 'right',
  },
});

export default ContentCard;