import axios from 'axios';

// Replace with your actual API URL
const API_URL = 'http://localhost:3000';

const api = axios.create({
  baseURL: API_URL,
  headers: {
    'Content-Type': 'application/json',
  },
  withCredentials: true,
});

// Authentication endpoints
export const login = async (username: string, password: string) => {
  try {
    const response = await api.post('/api/login', { username, password });
    return response.data;
  } catch (error) {
    console.error('Login error:', error);
    throw error;
  }
};

export const logout = async () => {
  try {
    const response = await api.post('/api/logout');
    return response.data;
  } catch (error) {
    console.error('Logout error:', error);
    throw error;
  }
};

export const getCurrentUser = async () => {
  try {
    const response = await api.get('/api/user');
    return response.data;
  } catch (error) {
    console.error('Get user error:', error);
    throw error;
  }
};

// Content endpoints
export const getRecentContent = async (limit = 10) => {
  try {
    const response = await api.get(`/api/recent-content?limit=${limit}`);
    return response.data;
  } catch (error) {
    console.error('Get recent content error:', error);
    throw error;
  }
};

export const getMovies = async () => {
  try {
    const response = await api.get('/api/movies');
    return response.data;
  } catch (error) {
    console.error('Get movies error:', error);
    throw error;
  }
};

export const getMovie = async (id: number) => {
  try {
    const response = await api.get(`/api/movies/${id}`);
    return response.data;
  } catch (error) {
    console.error(`Get movie ${id} error:`, error);
    throw error;
  }
};

export const getAllSeries = async () => {
  try {
    const response = await api.get('/api/series');
    return response.data;
  } catch (error) {
    console.error('Get series error:', error);
    throw error;
  }
};

export const getSeries = async (id: number) => {
  try {
    const response = await api.get(`/api/series/${id}`);
    return response.data;
  } catch (error) {
    console.error(`Get series ${id} error:`, error);
    throw error;
  }
};

export const getEpisodes = async (seriesId: number) => {
  try {
    const response = await api.get(`/api/episodes?seriesId=${seriesId}`);
    return response.data;
  } catch (error) {
    console.error(`Get episodes for series ${seriesId} error:`, error);
    throw error;
  }
};

export const getEpisode = async (id: number) => {
  try {
    const response = await api.get(`/api/episodes/${id}`);
    return response.data;
  } catch (error) {
    console.error(`Get episode ${id} error:`, error);
    throw error;
  }
};

export const getChannels = async () => {
  try {
    const response = await api.get('/api/channels');
    return response.data;
  } catch (error) {
    console.error('Get channels error:', error);
    throw error;
  }
};

export const getChannel = async (id: number) => {
  try {
    const response = await api.get(`/api/channels/${id}`);
    return response.data;
  } catch (error) {
    console.error(`Get channel ${id} error:`, error);
    throw error;
  }
};

export const getMatches = async () => {
  try {
    const response = await api.get('/api/matches');
    return response.data;
  } catch (error) {
    console.error('Get matches error:', error);
    throw error;
  }
};

export const getMatch = async (id: number) => {
  try {
    const response = await api.get(`/api/matches/${id}`);
    return response.data;
  } catch (error) {
    console.error(`Get match ${id} error:`, error);
    throw error;
  }
};

// Category endpoints
export const getCategories = async () => {
  try {
    const response = await api.get('/api/categories');
    return response.data;
  } catch (error) {
    console.error('Get categories error:', error);
    throw error;
  }
};

export const getSubcategories = async (categoryId: number) => {
  try {
    const response = await api.get(`/api/subcategories?parentCategoryId=${categoryId}`);
    return response.data;
  } catch (error) {
    console.error(`Get subcategories for category ${categoryId} error:`, error);
    throw error;
  }
};

// Video playback functions
export const getVideoData = async (videoId: number, videoType: string) => {
  try {
    let endpoint = '';
    switch (videoType) {
      case 'movie':
        endpoint = `/api/movies/${videoId}`;
        break;
      case 'episode':
        endpoint = `/api/episodes/${videoId}`;
        break;
      case 'channel':
        endpoint = `/api/channels/${videoId}`;
        break;
      case 'match':
        endpoint = `/api/matches/${videoId}`;
        break;
      default:
        throw new Error('Invalid video type');
    }
    
    const response = await api.get(endpoint);
    return response.data;
  } catch (error) {
    console.error(`Get video data error for ${videoType} ${videoId}:`, error);
    throw error;
  }
};

// App settings
export const getSettings = async () => {
  try {
    const response = await api.get('/api/settings');
    return response.data;
  } catch (error) {
    console.error('Get settings error:', error);
    throw error;
  }
};

export default api;